Contains 8 functions:

1. This returns all items under "hashtag". 
It has 1 argument, enter the hashtag path from the event

2. This returns all items under "symbols". 
It has 1 argument, enter the symbols path from the event

3. This returns all items under "user_mentions". 
It has 1 argument, enter the user_mentions path from the event

4. This returns all items under "media". 
It has 1 argument, enter the media path from the event

5. This returns all items under "extended". 
It has 1 argument, enter the extended path from the event

6. This returns all items under "user_urls". 
It has 1 argument, enter the user_urls path from the event

7. This returns all items under "single_items". 
It has 1 argument, enter the single_items path from the event

8. This returns all items under "entities_urls". 
It has 1 argument, enter the urls path from the event